Meyer Lemon Poppyseed Tea Cakes - Crumb: A Food Blog
Description: These sunny bite-sized cakes are crispy around the edges and slightly chewy in the middle, with loads of tangy Meyer lemon flavour.
Date: 2018-03-19T07:24:37-04:00

# Sunny Days: Meyer Lemon Poppyseed Tea Cakes

March 19, 2018 By Isabelle Boucher 2 Comments | Filed Under: cake, dessert, winter

These past few months of winter have felt a little short on sunshine, both literally and metaphorically.

Without getting too far into the details, suffice to say that there’s been more than the usual share of dreary days, like I’ve got a personal-sized rain cloud following me wherever I go. (Or maybe a snow cloud… there’s been plenty of that, too.)

As is often the case when the going gets rough, I’ve been doing a whole lot of therapeutic baking. I like to believe that, in copious quantities, butter and sugar have the magical ability to make everything feel a little better, even if it’s only temporary.

Take these two-bite teacakes – they’re a bite like edible sunshine, a perfect antidote to these grey days.

They’re dense and sweet, with crispy golden edges and a slightly chewy centre, with a knock-you-upside-the-head lemon flavour that’s amplified by a final brushing of lemon syrup.

These simple cakes started off as a serendipitous accident – a Martha Stewart recipe for lemon-lime tea cakes that neglected to include a very important “divided” after the sugar measurement, which in turn resulted in me adding a double-dose of sugar in the batter.

Thankfully, instead of disaster, I ended up with a batch of delightfully dense and slightly chewy bite-sized cakes that paired perfectly with a mug of strong black tea. Think classic buttery French financiers, only without the nuts.

They’ve become one of my go-to recipes when I need a burst of sunshine in my life, either plain or dotted with crunchy poppy seeds as I’ve done here.

When made with Meyer lemons, their sunny lemon flavour takes on a subtly floral note, but they’re quite lovely made with regular lemons if you can’t get your hands on some Meyers. Heck, they’d be pretty lovely made with grapefruit or blood orange, too. Or go all out with a combo of your favourite citrus fruits.

Much like any cure, two of these and a good night’s sleep make for a sunnier morning. Perhaps not literally, but certainly metaphorically.

//

Print

## Meyer Lemon Poppyseed Tea Cakes

- Author: Isabelle Boucher (Crumb_
- Prep Time: 10 mins
- Cook Time: 20 mins
- Total Time: 30 minutes
- Yield: 24
- Category: Desserts
- Cuisine: French

Print Recipe
Pin Recipe

### Description

These sunny bite-sized tea cakes are crispy around the edges and slightly chewy in the middle, with a tangy and subtly floral Meyer lemon flavour.

### Ingredients

Tea Cakes:

- 1/2 cup unsalted butter, softened
- 1 1/4 cups sugar
- 1 tbsp grated Meyer lemon zest
- 2 tbsp fresh-squeezed Meyer lemon juice
- 2 large eggs
- 1 cup all-purpose flour
- 1/4 cup poppy seeds
- 1/2 tsp salt

Lemon Syrup:

- 1/2 cup water
- 1/2 cup sugar
- 1 Meyer lemon, cut into slices

### Instructions

1. Preheat oven to 350 degrees. Lightly butter a 24-cup mini-muffin pan.
2. In a large bowl, beat butter, sugar, and lemon zest until light and creamy. Stir in the lemon juice and eggs, and mix well. Gradually add the flour, poppy seeds and salt, stirring until combined.
3. Spoon the batter into the prepared muffin tin, dividing evenly. Bake in preheated oven for 18-20 minutes, or until the cakes are golden around edges and a toothpick inserted in center comes out clean.
4. While the cakes are baking, make the syrup. Combine the water and sugar in a small saucepan set over medium heat, and bring to a simmer. Add the lemon slices, and cook for 5 minutes or until the lemon is soft. Remove from heat, and set aside to cool until the cakes are done.
5. Using a toothpick, poke holes all over the tops of the cakes as soon as they come out of the oven. Drizzle with the lemon syrup over each cake. Let the cakes cool in the pan for 10 minutes, then transfer to a wire rack to cool completely.

### You might also like...

- Sunny Days: Seville Orange Polenta Cake
- Main Squeeze: One Pan Meyer Lemon Chicken Bake
- The Great Pumpkin: Sticky Pumpkin Spice Gingerbread Cake
- Sticky, Spicy, Sweet – Sticky Gingerbread w/ Poached Persimmons

Pin102
Share18
Yum3
Email
+1
Reddit
Flip
Tweet
Shares 123

### Comments

1. Shareba says

   March 19, 2018 at 3:34 pm

   I love it when kitchen flubs turn into something yummy! These look so good – I’m craving a cup of tea now.

   Reply

2. Riz | Chocolates & Chai says

   March 19, 2018 at 2:24 pm

   Ahhh, lemon and poppyseed is one of my favourite combinations. It’s perfect in madeleines, cakes, and tea cakes, just like yours!

   Reply

### Leave a Reply Cancel reply

Your email address will not be published. Required fields are marked *

Rate this recipe ★☆ ★☆ ★☆ ★☆ ★☆

Comment

Name *

Email *

Website

Save my name, email, and website in this browser for the next time I comment.